Innovation Sandbox (Python)
===========================
.. image:: https://travis-ci.org/enyata/innovation-sandbox-python.svg?branch=master
    :target: https://travis-ci.org/enyata/innovation-sandbox-python


| A Python module that gives access to the innovation sandbox API on the go!

Features
~~~~~~~~

* Super easy to use
* Very easy to understand
* Get the code right in your editor

Installation
~~~~~~~~~~~~

* Just fire the following command in your terminal:

.. code:: bash

   pip3 install innovation-sandbox

- | It's that easy. If you are using Python 2.7 use pip instead. Depending on your
  | permissions, you might need to use ``pip install --user innovation-sandbox`` to install.

* Or you can download the source code from `here <https://github.com/enyata/innovation-sandbox-python>`_, and then just install the package using

.. code:: bash

    python setup.py install

~~~~~~~~~~~~~~~~~

Quick Start Guide
~~~~~~~~~~~~~~~~~

* To get started with the nibss documentation, check out: `NIBSS <https://github.com/enyata/innovation-sandbox-python/blob/master/nibss/README.rst>`_.

* To get started with the sterling documentation, check out: `STERLING <https://github.com/enyata/innovation-sandbox-python/blob/master/sterling/README.rst>`_.

Tests
~~~~~

* Just type in the following command to run the tests

.. code:: bash

    py.test

* This will run the test defined in the files of the ``tests/`` directory

Dependencies
~~~~~~~~~~~~

* To Download and install all the module dependencies, just type

.. code:: bash

    pip install -r requirements.txt

* And voila! All of the program’s “dependencies” will be downloaded, installed, and ready to go in one fell swoopidy-woop.
